@@ -11,7 +11,7 @@ Software::License::GFDL_1_2 - The GNU Free Documentation License
 
 sub name { 'GNU Free Documentation License' }
 sub url  { 'http://www.gnu.org/copyleft/fdl.html' }
-sub meta_yml_name { 'unrestricted' }
+sub meta_name { 'unrestricted' }
 
 1;
 __DATA__
